@@ -1,8 +1,10 @@
 msgfmt pt/tqslapp.po -o pt/tqslapp.mo
 msgfmt ja/tqslapp.po -o ja/tqslapp.mo
 msgfmt it/tqslapp.po -o it/tqslapp.mo
+msgfmt fi/tqslapp.po -o fi/tqslapp.mo
 msgfmt fr/tqslapp.po -o fr/tqslapp.mo
 msgfmt es/tqslapp.po -o es/tqslapp.mo
 msgfmt de/tqslapp.po -o de/tqslapp.mo
 msgfmt zh/tqslapp.po -o zh/tqslapp.mo
 msgfmt ru/tqslapp.po -o ru/tqslapp.mo
+msgfmt pl/tqslapp.po -o pl/tqslapp.mo
