@@ -199,6 +199,7 @@ static const wxLanguage langIds[] = {
     wxLANGUAGE_DEFAULT,
     wxLANGUAGE_CHINESE,
     wxLANGUAGE_ENGLISH,
+    wxLANGUAGE_FINNISH,
     wxLANGUAGE_FRENCH,
     wxLANGUAGE_GERMAN,
     wxLANGUAGE_ITALIAN,
@@ -214,6 +215,7 @@ const wxString langNames[] = {
     wxT("System default"),
     wxT("Chinese"),
     wxT("English"),
+    wxT("Finnish"),
     wxT("French"),
     wxT("German"),
     wxT("Italian"),
