@@ -21,7 +21,7 @@ void displayCertProperties(CertTreeItemData *item, wxWindow *parent = 0);
 void displayLocProperties(LocTreeItemData *item, wxWindow *parent = 0);
 int getPassword(char *buf, int bufsiz, void *);
 void displayTQSLError(const char *pre);
-wxMenu *makeCertificateMenu(bool enable, bool keyonly = false);
+wxMenu *makeCertificateMenu(bool enable, bool keyonly = false, const char* callsign = NULL);
 wxMenu *makeLocationMenu(bool enable);
 
 #endif	// __util_h
